## 3.1.0.2 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 3.1.0.1 (2023-02-15)

Use `typing_extensions.Self` instead of `_typeshed.Self` (#9702)

## 3.1.0.0 (2022-12-24)

Add stub for ibm_db (#9325)

Co-authored-by: Jelle Zijlstra <jelle.zijlstra@gmail.com>

